==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/named/constraints/constraint/SrlgNamesKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints.constraint;

import java.lang.String;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of srlgNames.
 */
public class SrlgNamesKeys implements KeyInfo<DefaultSrlgNames> {
    protected String name;
    /**
     * Returns the attribute name.
     *
     * @return name value of name
     */
    public String name() {
        return name;
    }

    /**
     * Sets the value to attribute name.
     *
     * @param name value of name
     */
    public void name(String name) {
        this.name = name;
    }


    @Override
    public int hashCode() {
        return Objects.hash(name);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SrlgNamesKeys) {
            SrlgNamesKeys other = (SrlgNamesKeys) obj;
            return
                Objects.equals(name, other.name);
        }
        return false;
    }
}

==> onos-yang-runtime-2.4.4-sources.jar: org/onosproject/yang/gen/v1/yrtietftetypes/rev20160320/yrtietftetypes/tunnelpathsrlgs/tunnelpathsrlgs/style/named/constraints/constraint/SrlgNamesKeys.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetypes.rev20160320.yrtietftetypes.tunnelpathsrlgs.tunnelpathsrlgs.style.named.constraints.constraint;

import java.lang.String;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of srlgNames.
 */
public class SrlgNamesKeys implements KeyInfo<DefaultSrlgNames> {
    protected String name;
    /**
     * Returns the attribute name.
     *
     * @return name value of name
     */
    public String name() {
        return name;
    }

    /**
     * Sets the value to attribute name.
     *
     * @param name value of name
     */
    public void name(String name) {
        this.name = name;
    }


    @Override
    public int hashCode() {
        return Objects.hash(name);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof SrlgNamesKeys) {
            SrlgNamesKeys other = (SrlgNamesKeys) obj;
            return
                Objects.deepEquals(name, other.name);
        }
        return false;
    }
}
